@@ -1,7 +1,7 @@
 package Module::FatPack;
 
-our $DATE = '2015-06-17'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-07-03'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -91,13 +91,13 @@ sub fatpack_modules {
     my %module_srcs; # key: mod_pm
     if ($args{module_srcs}) {
         for my $mod (keys %{ $args{module_srcs} }) {
-            my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
+            my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm" unless $mod_pm =~ /\.pm\z/;
             $module_srcs{$mod_pm} = $args{module_srcs}{$mod};
         }
     } else {
         require Module::Path::More;
         for my $mod (@{ $args{module_names} }) {
-            my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
+            my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm" unless $mod_pm =~ /\.pm\z/;
             next if $module_srcs{$mod_pm};
             my $path = Module::Path::More::module_path(
                 module => $mod, find_pmc=>0);
@@ -209,7 +209,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.06 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-17.
+This document describes version 0.07 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-07-03.
 
 =head1 SEE ALSO
 
@@ -270,32 +270,22 @@ Whether to strip included modules using Perl::Stripper.
 
 Set strip_comment=1 (strip comments) in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<stripper_log> => I<bool> (default: 0)
 
 Set strip_log=1 (strip log statements) in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<stripper_maintain_linum> => I<bool> (default: 0)
 
 Set maintain_linum=1 in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<stripper_pod> => I<bool> (default: 1)
 
 Set strip_pod=1 (strip POD) in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<stripper_ws> => I<bool> (default: 1)
 
 Set strip_ws=1 (strip whitespace) in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =back
 
 Returns an enveloped result (an array).
